Learn R Programming

TreeDist (version 1.1.1)

Entropy: Entropy in bits

Description

Calculate the entropy of a vector of probabilities, in bits. Probabilities should sum to one. Probabilities equalling zero will be ignored.

Usage

Entropy(...)

Arguments

…

Numerics or numeric vector specifying probabilities of outcomes.

Value

Entropy() returns the entropy of the specified probabilities, in bits.

Examples

Run this code
# NOT RUN {
Entropy(1/2, 0, 1/2) # = 1
Entropy(rep(1/4, 4)) # = 2
# }

Run the code above in your browser using DataLab