View source: R/tree_information.R
| MCITree | R Documentation |
Analogous to the Maximum Clade Credibility tree:
select the tree from a posterior distribution whose clades have the
highest information content.
Generate the MCC tree by specifying info = "credibility".
MCITree(trees, info = "phylogenetic", check.tips = TRUE)
trees |
List of |
info |
Abbreviation of "phylogenetic" or "clustering", specifying the concept of information to employ. |
check.tips |
Logical specifying whether to renumber leaves such that leaf numbering is consistent in all trees. |
MCITree() returns the tree with the highest information
content, selected from trees.
Martin R. Smith (martin.smith@durham.ac.uk)
Other summary trees:
TransferConsensus()
library("TreeTools", quietly = TRUE)
trees <- as.phylo(24:40, 16)
# Maximum Clade Information tree
mci <- MCITree(trees)
SplitwiseInfo(mci)
plot(mci)
p <- SplitFrequency(mci, trees) / length(trees)
LabelSplits(mci, round(p * 100), "%", bg = SupportColor(p))
# Compare with Maximum Clade Credibility tree
mcc <- MCITree(trees, "credibility")
plot(mcc)
p <- SplitFrequency(mcc, trees) / length(trees)
LabelSplits(mcc, round(p * 100), "%", bg = SupportColor(p))
SplitwiseInfo(mcc)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.