| cpp_transfer_dist | R Documentation |
Per-pair transfer dissimilarity
cpp_transfer_dist(x, y, nTip)
x, y |
Raw matrices representing splits (from as.Splits()). |
nTip |
Integer: number of tips. |
A list with components:
score_scaled: scaled transfer dissimilarity (double)
score_unscaled: unscaled transfer dissimilarity (double)
matching_xy: integer vector, best match in y for each split in x (1-based, NA if sentinel)
matching_yx: integer vector, best match in x for each split in y (1-based, NA if sentinel)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.