entropy_int: Calculate entropy of integer vector of counts

View source: R/RcppExports.R

entropy_intR Documentation

Calculate entropy of integer vector of counts

Description

Wrapper for C++ function; no input checking is performed. Ntropy() is better suited for use where performance is not critical.

Usage

entropy_int(n)

Arguments

n

a vector of integer counts

Value

entropy_int() returns a numeric corresponding to the entropy of each observation, in bits.


TreeDist documentation built on June 10, 2026, 5:06 p.m.