Per-pair transfer dissimilarity
cpp_transfer_dist(x, y, nTip)A list with components:
score_scaled: scaled transfer dissimilarity (double)
score_unscaled: unscaled transfer dissimilarity (double)
matching_xy: integer vector, best match in y for each split in x (1-based, NA if sentinel)
matching_yx: integer vector, best match in x for each split in y (1-based, NA if sentinel)
Raw matrices representing splits (from as.Splits()).
Integer: number of tips.